==> haskell-sop-core-0.5.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sop-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sop-core
version:              0.5.0.1
visibility:           public
id:                   sop-core-0.5.0.1-DRjYElI1EPTKAV573Fpd8I
key:                  sop-core-0.5.0.1-DRjYElI1EPTKAV573Fpd8I
license:              BSD-3-Clause
maintainer:           andres@well-typed.com
author:
    Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>

synopsis:             True Sums of Products
description:
    Implementation of n-ary sums and n-ary products.

    The module "Data.SOP" is the main module of this library and contains
    more detailed documentation.

    The main use case of this package is to serve as the core of
    @<https://hackage.haskell.org/package/generics-sop generics-sop>@.

    A detailed description of the ideas behind this library is provided by
    the paper:

    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.

category:             Data
abi:                  0ea4eb5f5df443174f82d9d8dc177197
exposed:              True
exposed-modules:
    Data.SOP Data.SOP.BasicFunctors Data.SOP.Classes
    Data.SOP.Constraint Data.SOP.Dict Data.SOP.NP Data.SOP.NS
    Data.SOP.Sing

import-dirs:          /usr/lib/ghc-8.10.5/site-local/sop-core-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/sop-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/sop-core-0.5.0.1
hs-libraries:         HSsop-core-0.5.0.1-DRjYElI1EPTKAV573Fpd8I
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-sop-core/html/sop-core.haddock
haddock-html:         /usr/share/doc/haskell-sop-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sop-core-0.5.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sop-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sop-core
version:              0.5.0.1
visibility:           public
id:                   sop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr
key:                  sop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr
license:              BSD-3-Clause
maintainer:           andres@well-typed.com
author:
    Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>

synopsis:             True Sums of Products
description:
    Implementation of n-ary sums and n-ary products.

    The module "Data.SOP" is the main module of this library and contains
    more detailed documentation.

    The main use case of this package is to serve as the core of
    @<https://hackage.haskell.org/package/generics-sop generics-sop>@.

    A detailed description of the ideas behind this library is provided by
    the paper:

    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.

category:             Data
abi:                  83e695af3c4fe9965a739a3fe984c30d
exposed:              True
exposed-modules:
    Data.SOP Data.SOP.BasicFunctors Data.SOP.Classes
    Data.SOP.Constraint Data.SOP.Dict Data.SOP.NP Data.SOP.NS
    Data.SOP.Sing

import-dirs:          /usr/lib/ghc-9.0.1/site-local/sop-core-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/sop-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/sop-core-0.5.0.1
hs-libraries:         HSsop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-sop-core/html/sop-core.haddock
haddock-html:         /usr/share/doc/haskell-sop-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
